@@ -1,7 +1,7 @@
 
-/* 
+/*
 
-  Example C routine for how to use callext() in PDL 
+  Example C routine for how to use callext() in PDL
   - return log x to base y vector.
 
   E.g. on Solaris this would be compiled:
@@ -9,13 +9,25 @@
   cc -o callext.so -G -Kpic callext.c
 
   to generate dynamically loadable code. For other systems
-  see the man pages on your C compiler or the Perl config 
+  see the man pages on your C compiler or the Perl config
   information.
 
 */
 
 #include <stdio.h>
 #include <math.h>
+
+/* For WindowsNT you have to make sure that the relevant routine
+   is exported by the dll otherwise it will not be loadable even if it
+   can be linked. In this example we use the __declspec declaration.
+   The same effect can be achieved with .def files although currently
+   CallExt.pm does not know to use them */
+#ifdef WIN32
+#define DLLEXPORT __declspec(dllexport)
+#else
+#define DLLEXPORT
+#endif
+
 #include "pdlsimple.h"
 
 /* This is the action routine */
@@ -28,12 +40,12 @@ void loglog_doit( float *x, float *y, int nvals) {
       x[i] = log((float)x[i])/log((float)y[i]);
 }
 
-/* 
+/*
    This is the hook routine - nargs is the number of
    arguments and *args is an array of pdl structures
 */
 
-int loglog_ext(int nargs, pdlsimple **args) {
+DLLEXPORT int loglog_ext(int nargs, pdlsimple **args) {
 
    pdlsimple* x;
    pdlsimple* y;
@@ -48,9 +60,9 @@ int loglog_ext(int nargs, pdlsimple **args) {
    }
 
    x = args[0]; y = args[1];
-       
+
    if (x->datatype != PDL_F || y->datatype != PDL_F) {
-      fprintf(stderr, "Error in data type of arguments %d %d\n", 
+      fprintf(stderr, "Error in data type of arguments %d %d\n",
               x->datatype, y->datatype);
       return (0); /* Failure */
    }
@@ -62,7 +74,7 @@ int loglog_ext(int nargs, pdlsimple **args) {
 
    /* Now do the buisness! */
 
-   loglog_doit( (float*) x->data, (float*) y->data, x->nvals); 
+   loglog_doit( (float*) x->data, (float*) y->data, x->nvals);
 
    return(1);  /* Success! */
 }
